# eric7.HelpViewer.HelpViewerImplQWE

Module implementing the help viewer base class.

### Global Attributes

None

### Classes

HelpViewerImplQWE | Class implementing the QTextBrowser based help viewer class.

### Functions

None

## HelpViewerImplQWE

Class implementing the QTextBrowser based help viewer class.

### Derived from

HelpViewerImpl, QWebEngineView

### Class Attributes

ZoomLevelDefault
ZoomLevels

### Class Methods

None

### Methods

HelpViewerImplQWE | Constructor
__bookmarkPage | Private method called by the context menu to bookmark the page.
__closeOtherPages | Private method called by the context menu to close all other pages.
__closePage | Private method called by the context menu to close the current page.
__copyLink | Private method called by the context menu to copy a link to the clipboard.
__copyText | Private method called by the context menu to copy selected text to the clipboard.
__createContextMenu | Private method to populate the context menu.
__createLinkContextMenu | Private method to populate the context menu for URLs.
__createNewPage | Private method to create a new page object.
__levelForScale | Private method determining the zoom level index given a zoom factor.
__newWindowRequested | Private slot handling new window requests of the web page.
__openLinkInBackgroundPage | Private method called by the context menu to open a link in a background page.
__openLinkInNewPage | Private method called by the context menu to open a link in a new page.
__selectAll | Private method called by the context menu to select all text.
__setRwhvqt | Private slot to set widget that receives input events.
__titleChanged | Private method to handle a change of the web page title.
_contextMenuEvent | Protected method called to create a context menu.
_gestureEvent | Protected method handling gesture events.
_keyPressEvent | Protected method called by a key press.
_mouseReleaseEvent | Protected method called by a mouse release event.
_wheelEvent | Protected method to handle wheel events.
backward | Public slot to move backwards in history.
backwardHistoryCount | Public method to get the number of available back history items.
clearHistory | Public method to clear the history.
contextMenuEvent | Protected method called to create a context menu.
event | Public method handling events.
eventFilter | Public method to process event for other objects.
forward | Public slot to move forward in history.
forwardHistoryCount | Public method to get the number of available forward history items.
gotoHistory | Public method to go to a history item.
historyTitle | Public method to get the title of a history item.
isBackwardAvailable | Public method to check, if stepping backward through the history is available.
isEmptyPage | Public method to check, if the current page is the empty page.
isForwardAvailable | Public method to check, if stepping forward through the history is available.
isScaleDownAvailable | Public method to check, if the min.
isScaleUpAvailable | Public method to check, if the max.
link | Public method to get the URL of the shown document.
pageTitle | Public method get the page title.
reload | Public slot to reload the current page.
resetScale | Public method to reset the zoom level.
scale | Public method to get the zoom level.
scaleDown | Public method to zoom out.
scaleUp | Public method to zoom in.
setLink | Public method to set the URL of the document to be shown.
setScale | Public method to set the zoom level.

### Static Methods

None

#### HelpViewerImplQWE (Constructor)

HelpViewerImplQWE(engine, parent=None)

Constructor

engine (QHelpEngine)
  reference to the help engine
parent (QWidget)
  reference to the parent widget

#### HelpViewerImplQWE.__bookmarkPage

__bookmarkPage(act)

Private method called by the context menu to bookmark the page.

act (QAction)
  reference to the action that triggered

#### HelpViewerImplQWE.__closeOtherPages

__closeOtherPages()

Private method called by the context menu to close all other pages.

#### HelpViewerImplQWE.__closePage

__closePage()

Private method called by the context menu to close the current page.

#### HelpViewerImplQWE.__copyLink

__copyLink(act)

Private method called by the context menu to copy a link to the clipboard.

act (QAction)
  reference to the action that triggered

#### HelpViewerImplQWE.__copyText

__copyText()

Private method called by the context menu to copy selected text to the clipboard.

#### HelpViewerImplQWE.__createContextMenu

__createContextMenu(menu)

Private method to populate the context menu.

menu (QMenu)
  reference to the menu to be populated

#### HelpViewerImplQWE.__createLinkContextMenu

__createLinkContextMenu(menu, contextMenuData)

Private method to populate the context menu for URLs.

menu (QMenu)
  reference to the menu to be populated
contextMenuData (QWebEngineContextMenuRequest)
  data of the last context menu request

#### HelpViewerImplQWE.__createNewPage

__createNewPage()

Private method to create a new page object.

#### HelpViewerImplQWE.__levelForScale

__levelForScale(scale)

Private method determining the zoom level index given a zoom factor.

scale (int)
  zoom factor

Return:
  index of zoom factor

Return Type:
  int

#### HelpViewerImplQWE.__newWindowRequested

__newWindowRequested(request)

Private slot handling new window requests of the web page.

request (QWebEngineNewWindowRequest)
  reference to the new window request

#### HelpViewerImplQWE.__openLinkInBackgroundPage

__openLinkInBackgroundPage(act)

Private method called by the context menu to open a link in a background page.

act (QAction)
  reference to the action that triggered

#### HelpViewerImplQWE.__openLinkInNewPage

__openLinkInNewPage(act)

Private method called by the context menu to open a link in a new page.

act (QAction)
  reference to the action that triggered

#### HelpViewerImplQWE.__selectAll

__selectAll()

Private method called by the context menu to select all text.

#### HelpViewerImplQWE.__setRwhvqt

__setRwhvqt()

Private slot to set widget that receives input events.

#### HelpViewerImplQWE.__titleChanged

__titleChanged()

Private method to handle a change of the web page title.

#### HelpViewerImplQWE._contextMenuEvent

_contextMenuEvent(evt)

Protected method called to create a context menu.

evt
  reference to the context menu event object (QContextMenuEvent)

#### HelpViewerImplQWE._gestureEvent

_gestureEvent(evt)

Protected method handling gesture events.

evt (QGestureEvent)
  reference to the gesture event

#### HelpViewerImplQWE._keyPressEvent

_keyPressEvent(evt)

Protected method called by a key press.

evt (QKeyEvent)
  reference to the key event

#### HelpViewerImplQWE._mouseReleaseEvent

_mouseReleaseEvent(evt)

Protected method called by a mouse release event.

evt (QMouseEvent)
  reference to the mouse event

#### HelpViewerImplQWE._wheelEvent

_wheelEvent(evt)

Protected method to handle wheel events.

evt (QWheelEvent)
  reference to the wheel event

#### HelpViewerImplQWE.backward

backward()

Public slot to move backwards in history.

#### HelpViewerImplQWE.backwardHistoryCount

backwardHistoryCount()

Public method to get the number of available back history items.

Note: For performance reasons this is limited to the maximum number of history items the help viewer is interested in.

Return:
  count of available back history items

Return Type:
  int

#### HelpViewerImplQWE.clearHistory

clearHistory()

Public method to clear the history.

#### HelpViewerImplQWE.contextMenuEvent

contextMenuEvent(evt)

Protected method called to create a context menu.

This method is overridden from QWebEngineView.

evt (QContextMenuEvent)
  reference to the context menu event object

#### HelpViewerImplQWE.event

event(evt)

Public method handling events.

evt
  reference to the event (QEvent)

Return:
  flag indicating, if the event was handled (boolean)

#### HelpViewerImplQWE.eventFilter

eventFilter(obj, evt)

Public method to process event for other objects.

obj (QObject)
  reference to object to process events for
evt (QEvent)
  reference to event to be processed

Return:
  flag indicating that the event should be filtered out

Return Type:
  bool

#### HelpViewerImplQWE.forward

forward()

Public slot to move forward in history.

#### HelpViewerImplQWE.forwardHistoryCount

forwardHistoryCount()

Public method to get the number of available forward history items.

Note: For performance reasons this is limited to the maximum number of history items the help viewer is interested in.

Return:
  count of available forward history items

Return Type:
  int

#### HelpViewerImplQWE.gotoHistory

gotoHistory(offset)

Public method to go to a history item.

offset (int)
  offset of the item with respect to the current page

#### HelpViewerImplQWE.historyTitle

historyTitle(offset)

Public method to get the title of a history item.

offset (int)
  offset of the item with respect to the current page

Return:
  title of the requeted item in history

Return Type:
  str

#### HelpViewerImplQWE.isBackwardAvailable

isBackwardAvailable()

Public method to check, if stepping backward through the history is available.

Return:
  flag indicating backward stepping is available

Return Type:
  bool

#### HelpViewerImplQWE.isEmptyPage

isEmptyPage()

Public method to check, if the current page is the empty page.

Return:
  flag indicating an empty page is loaded

Return Type:
  bool

#### HelpViewerImplQWE.isForwardAvailable

isForwardAvailable()

Public method to check, if stepping forward through the history is available.

Return:
  flag indicating forward stepping is available

Return Type:
  bool

#### HelpViewerImplQWE.isScaleDownAvailable

isScaleDownAvailable()

Public method to check, if the min. zoom level is reached.

Return:
  flag indicating scale down is available

Return Type:
  bool

#### HelpViewerImplQWE.isScaleUpAvailable

isScaleUpAvailable()

Public method to check, if the max. zoom level is reached.

Return:
  flag indicating scale up is available

Return Type:
  bool

#### HelpViewerImplQWE.link

link()

Public method to get the URL of the shown document.

Return:
  url URL of the document

Return Type:
  QUrl

#### HelpViewerImplQWE.pageTitle

pageTitle()

Public method get the page title.

Return:
  page title

Return Type:
  str

#### HelpViewerImplQWE.reload

reload()

Public slot to reload the current page.

#### HelpViewerImplQWE.resetScale

resetScale()

Public method to reset the zoom level.

#### HelpViewerImplQWE.scale

scale()

Public method to get the zoom level.

Return:
  current zoom level

Return Type:
  int

#### HelpViewerImplQWE.scaleDown

scaleDown()

Public method to zoom out.

#### HelpViewerImplQWE.scaleUp

scaleUp()

Public method to zoom in.

#### HelpViewerImplQWE.setLink

setLink(url)

Public method to set the URL of the document to be shown.

url (QUrl)
  URL of the document

#### HelpViewerImplQWE.setScale

setScale(scale)

Public method to set the zoom level.

scale (int)
  zoom level to set

Up